@@ -1415,8 +1415,9 @@ class Robot(object):
         Examples
         --------
 
-        >>> robot.client = RosClient()
-        >>> robot.client.run()
+        >>> ros = RosClient()
+        >>> ros.run()
+        >>> robot = ros.load_robot()
         >>> frames = [Frame([0.3, 0.1, 0.5], [1, 0, 0], [0, 1, 0]),\
                       Frame([0.5, 0.1, 0.6], [1, 0, 0], [0, 1, 0])]
         >>> start_configuration = Configuration.from_revolute_values([-0.042, 0.033, -2.174, 5.282, -1.528, 0.000])
@@ -1430,7 +1431,7 @@ class Robot(object):
                                                      options=options)
         >>> len(trajectory.points) > 1
         True
-        >>> robot.client.close()
+        >>> ros.close()
         """
         options = options or {}
         max_step = options.get('max_step')
@@ -1544,8 +1545,9 @@ class Robot(object):
 
         Using position and orientation constraints:
 
-        >>> robot.client = RosClient()
-        >>> robot.client.run()
+        >>> ros = RosClient()
+        >>> ros.run()
+        >>> robot = ros.load_robot()
         >>> frame = Frame([0.4, 0.3, 0.4], [0, 1, 0], [0, 0, 1])
         >>> tolerance_position = 0.001
         >>> tolerances_axes = [math.radians(1)] * 3
@@ -1553,28 +1555,29 @@ class Robot(object):
         >>> group = robot.main_group_name
         >>> goal_constraints = robot.constraints_from_frame(frame, tolerance_position, tolerances_axes, group)
         >>> robot.attached_tool = None
-        >>> trajectory = robot.plan_motion(goal_constraints, start_configuration, group, {'planner_id': 'RRTConnectkConfigDefault'})
+        >>> trajectory = robot.plan_motion(goal_constraints, start_configuration, group, {'planner_id': 'RRTConnect'})
         >>> trajectory.fraction
         1.0
         >>> len(trajectory.points) > 1
         True
-        >>> robot.client.close()
+        >>> ros.close()
 
         Using joint constraints (to the UP configuration):
 
-        >>> robot.client = RosClient()
-        >>> robot.client.run()
+        >>> ros = RosClient()
+        >>> ros.run()
+        >>> robot = ros.load_robot()
         >>> configuration = Configuration.from_revolute_values([0.0, -1.5707, 0.0, -1.5707, 0.0, 0.0])
         >>> tolerances_above = [math.radians(5)] * len(configuration.joint_values)
         >>> tolerances_below = [math.radians(5)] * len(configuration.joint_values)
         >>> group = robot.main_group_name
         >>> goal_constraints = robot.constraints_from_configuration(configuration, tolerances_above, tolerances_below, group)
-        >>> trajectory = robot.plan_motion(goal_constraints, start_configuration, group, {'planner_id': 'RRTConnectkConfigDefault'})
+        >>> trajectory = robot.plan_motion(goal_constraints, start_configuration, group, {'planner_id': 'RRTConnect'})
         >>> trajectory.fraction
         1.0
         >>> len(trajectory.points) > 1
         True
-        >>> robot.client.close()
+        >>> ros.close()
         """
         options = options or {}
         path_constraints = options.get('path_constraints')
@@ -1644,7 +1647,7 @@ class Robot(object):
         return trajectory
 
     def plan_motion_deprecated(self, goal_constraints, start_configuration=None,
-                               group=None, path_constraints=None, planner_id='RRTConnectkConfigDefault',
+                               group=None, path_constraints=None, planner_id='RRTConnect',
                                num_planning_attempts=1, allowed_planning_time=2.,
                                max_velocity_scaling_factor=1.,
                                max_acceleration_scaling_factor=1.,
